@@ -85,44 +85,3 @@ ptr_free(void* ptr)
 {
     free(ptr);
 }
-
-#define swap(p1, p2) do { typeof(*p1) tmp__ = *p1; *p1 = *p2; *p2 = tmp__; } while (0)
-void
-ptr_reverse_l6(long* l1, long* l2, long* l3, long* l4, long* l5, long* l6)
-{
-    swap(l1, l6);
-    swap(l2, l5);
-    swap(l3, l4);
-}
-
-void
-ptr_reverse_l5(long* l1, long* l2, long* l3, long* l4, long* l5)
-{
-    swap(l1, l5);
-    (void)(l3);
-    swap(l2, l4);
-}
-
-
-void
-ptr_rotate_l5(long* l1, long* l2, long* l3, long* l4, long* l5)
-{
-    long tmp = *l1;
-    swap(l5, l1);
-    swap(l4, l5);
-    swap(l3, l4);
-    swap(l2, l3);
-    *l2 = tmp;
-}
-
-void
-ptr_rotate_l6(long* l1, long* l2, long* l3, long* l4, long* l5, long* l6)
-{
-    long t = *l1;
-    swap(l6, l1);
-    swap(l5, l6);
-    swap(l4, l5);
-    swap(l3, l4);
-    swap(l2, l3);
-    *l2 = t;
-}
