@@ -1,13 +1,14 @@
 package jnr.ffi.provider;
 
 import jnr.ffi.TstUtil;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Test;
-
+import org.junit.jupiter.api.Test;
 import java.lang.reflect.Method;
 import java.util.Collection;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+
 public class InterfaceScannerTest {
     private static final Method SPLITERATOR;
 
@@ -23,14 +24,14 @@ public class InterfaceScannerTest {
 
     @Test public void loadTestLib() throws Exception {
         // If we're on Java 8+, proceed
-        Assume.assumeNotNull(SPLITERATOR);
+        assumeTrue(SPLITERATOR != null);
 
         Collection lib = TstUtil.loadTestLib(Collection.class);
 
         // spliterator function does not exist in the test lib, so this only works if we're skipping default methods
         Object spliterator = SPLITERATOR.invoke(lib);
 
-        Assert.assertNotNull(spliterator);
-        Assert.assertEquals("java.util.Spliterator", spliterator.getClass().getName());
+        assertNotNull(spliterator);
+        assertEquals("java.util.Spliterator", spliterator.getClass().getName());
     }
 }
