@@ -84,4 +84,41 @@ public class AsciiStringFieldTest {
         testlib.copyByteBuffer(tmp, s, s.string.length());
         assertEquals(MAGIC, tmp.toString(), "String not put into struct correctly");
     }
-}
\ No newline at end of file
+
+    public static final class StructWithStringByRef extends Struct {
+        private final AsciiStringRef stringValue = new AsciiStringRef();
+
+        public StructWithStringByRef() {
+            super(runtime);
+        }
+    }
+
+    @Test public void testStringByRef() {
+        final String testValue = "some test string";
+        final StructWithStringByRef struct = new StructWithStringByRef();
+
+        struct.stringValue.set(testValue);
+
+        assertEquals(testValue, struct.stringValue.get());
+    }
+
+    public static final class StructWithConsecutiveStringsByRef extends Struct {
+        private final AsciiStringRef firstValue = new AsciiStringRef();
+        private final AsciiStringRef secondValue = new AsciiStringRef();
+
+        public StructWithConsecutiveStringsByRef() {
+            super(runtime);
+        }
+    }
+
+    @Test public void testStructWithConsecutiveStringsByRef() {
+        final String testValue = "some test string";
+        final StructWithConsecutiveStringsByRef struct = new StructWithConsecutiveStringsByRef();
+
+        struct.firstValue.set("");
+        struct.secondValue.set(testValue);
+
+        assertEquals("", struct.firstValue.get());
+        assertEquals(testValue, struct.secondValue.get());
+    }
+}
