@@ -36,7 +36,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 public class UTF8StringFieldTest {
     public UTF8StringFieldTest() {
     }
-    
+
     public static class StringFieldStruct extends Struct {
         public final UTF8String string = new UTF8String(32);
 
@@ -105,4 +105,41 @@ public class UTF8StringFieldTest {
         assertEquals(SUN_FAM, s.sun_family.intValue(), "Incorrect sun_fam value");
         assertEquals(SUN_PATH, s.sun_path.toString(), "Incorrect sun_path value");
     }
-}
\ No newline at end of file
+
+    public static final class StructWithStringByRef extends Struct {
+        private final UTF8StringRef stringValue = new UTF8StringRef();
+
+        public StructWithStringByRef() {
+            super(runtime);
+        }
+    }
+
+    @Test public void testStringByRef() {
+        final String testValue = "some test string";
+        final StructWithStringByRef struct = new StructWithStringByRef();
+
+        struct.stringValue.set(testValue);
+
+        assertEquals(testValue, struct.stringValue.get());
+    }
+
+    public static final class StructWithConsecutiveStringsByRef extends Struct {
+        private final UTF8StringRef firstValue = new UTF8StringRef();
+        private final UTF8StringRef secondValue = new UTF8StringRef();
+
+        public StructWithConsecutiveStringsByRef() {
+            super(runtime);
+        }
+    }
+
+    @Test public void testStructWithConsecutiveStringsByRef() {
+        final String testValue = "some test string";
+        final StructWithConsecutiveStringsByRef struct = new StructWithConsecutiveStringsByRef();
+
+        struct.firstValue.set("");
+        struct.secondValue.set(testValue);
+
+        assertEquals("", struct.firstValue.get());
+        assertEquals(testValue, struct.secondValue.get());
+    }
+}
